function [data,varargout] = frextract(fname,cname,varargin)
% FrExtractm - extract from a frame file the data for one ADC channel
%
% [data,tsamp,fsamp,gps0,strStart,unitX,unitY] = ...
%    frgetvect(fname,cname,frameStart,nFrames,dbgLvl)
%
%      
% fname      - file name 
% cname      - ADC channel name
% frStart    - (optional) starting frame number (NOT GPS)(default: first frame in file)
% nFrames    - (optional) number of frames to read (default: one frame)
% dbgLvl     - (optional) debug level (default: 0 for no output)
% 
% data       - ADC data (time series stored as double)
% tsamp      - (optional) x (usually time) values relative to the first data point
% fsamp      - (optional) frequency values (for FFT's)
% gps0       - (optional) GPS starting time (in second, stored in double)
% gps0str    - (optional) starting time as a string
% unitX      - (optional) vector unitX as a string
% unitY      - (optional) vector unitY as a string
%
% Warning types:
%   frgetvect:info    -- informational messages
%   frgetvect:dt==0   -- channel metadata dt == 0
%
%  Error types:
%   frgetvect:inputArgCount    -- too many or too few input arguments
%   frgetvect:outputArgCount   -- too many or too few output arguments
%   frgetvect:inputArg         -- first two arguments are not strings
%   frgetvect:mxGetStringFail  -- memory allocation failure
%   frgetvect:fileOpen         -- failure to open file
%   frgetvect:channelNotFound  -- channel not in frame
%   frgetvect:noMatlabType     -- no matlab type for channel data

%#mex
%#external
